@@ -65,6 +65,31 @@ __wrap_setsockopt (__attribute__ ((unused)) int sockfd,
   return (int) mock (sockfd, level, optname, optval, optlen);
 }
 
+/* in_cksum */
+
+Ensure (util, in_cksum_small)
+{
+  int len;
+  // https://web.archive.org/web/20020916085726/http://www.netfor2.com/checksum.html
+  uint16_t data[] = {0x0100, 0xF203, 0xF4F5, 0xF6F7};
+
+  len = sizeof (data); // len is in bytes
+  assert_that (in_cksum ((uint16_t *) data, len), is_equal_to (0x210E));
+}
+
+Ensure (util, in_cksum_bigger)
+{
+  int len;
+  // https://en.wikipedia.org/wiki/Internet_checksum
+  uint16_t data[] = {0x4500, 0x0073, 0x0000, 0x4000, 0x4011,
+                     0xC0A8, 0x0001, 0xC0A8, 0x00C7};
+
+  len = sizeof (data); // len is in bytes
+  assert_that (in_cksum ((uint16_t *) data, len), is_equal_to (0xB861));
+}
+
+/* set_all_needed_sockets */
+
 Ensure (util, set_all_needed_sockets)
 {
   g_socket_use_real = false;
@@ -214,6 +239,8 @@ main (int argc, char **argv)
 
   suite = create_test_suite ();
 
+  add_test_with_context (suite, util, in_cksum_small);
+  add_test_with_context (suite, util, in_cksum_bigger);
   add_test_with_context (suite, util, fill_ports_array);
   add_test_with_context (suite, util, set_all_needed_sockets);
   add_test_with_context (suite, util, set_socket);
