@@ -11,64 +11,6 @@
 #define GVM_JSON_CHAR_ERROR -2     ///< Error reading file
 #define GVM_JSON_CHAR_UNDEFINED -3 ///< Undefined state
 
-/**
- * @brief Escapes a string according to the JSON or JSONPath standard
- *
- * @param[in]  string         The string to escape
- * @param[in]  single_quote   Whether to escape single quotes
- *
- * @return The escaped string
- */
-gchar *
-gvm_json_string_escape (const char *string, gboolean single_quote)
-{
-  gchar *point;
-  if (string == NULL)
-    return NULL;
-
-  GString *escaped = g_string_sized_new (strlen (string));
-  for (point = (char *) string; *point != 0; point++)
-    {
-      unsigned char character = *point;
-
-      if ((character > 31) && (character != '\\')
-          && (single_quote ? (character != '\'') : (character != '\"')))
-        {
-          g_string_append_c (escaped, character);
-        }
-      else
-        {
-          g_string_append_c (escaped, '\\');
-          switch (*point)
-            {
-            case '\\':
-            case '\'':
-            case '\"':
-              g_string_append_c (escaped, *point);
-              break;
-            case '\b':
-              g_string_append_c (escaped, 'b');
-              break;
-            case '\f':
-              g_string_append_c (escaped, 'f');
-              break;
-            case '\n':
-              g_string_append_c (escaped, 'n');
-              break;
-            case '\r':
-              g_string_append_c (escaped, 'r');
-              break;
-            case '\t':
-              g_string_append_c (escaped, 't');
-              break;
-            default:
-              g_string_append_printf (escaped, "u%04x", character);
-            }
-        }
-    }
-  return g_string_free (escaped, FALSE);
-}
-
 /**
  * @brief Creates a new JSON path element.
  *
